@@ -31,8 +31,14 @@ class Imagine:
         self.model_name = model_name
         self.half_mode = half_mode
         self.precision = precision
+        model_config = config.get_model_config(model_name)
+
+        if model_config is None:
+            raise ValueError(f"Unknown model name: {model_name}")
+
         self.sd_model = get_diffusion_model(
-            weights_location=model_name,
+            weights_location=model_config.weights_url,
+            config_path=model_config.config_path,
             half_mode=half_mode,
             for_inpainting=for_inpainting,
         )
